@@ -2,21 +2,21 @@ import subprocess
 from pathlib import Path
 from typing import Optional, Set, Tuple
 
-import toml
+import tomli
 
-from ..changelog import ChangeLog, in_development_header, version_header
-from ..configs import find_changelog_file, ProjectConfig
-from ..constants import (
+from badabump.changelog import ChangeLog, in_development_header, version_header
+from badabump.cli.output import diff, echo_message
+from badabump.configs import find_changelog_file, ProjectConfig
+from badabump.constants import (
     CHANGELOG_UPPER,
     FILE_PACKAGE_JSON,
     FILE_PACKAGE_LOCK_JSON,
     FILE_PYPROJECT_TOML,
     FILE_YARN_LOCK,
 )
-from ..enums import ChangeLogTypeEnum, FormatTypeEnum, ProjectTypeEnum
-from ..exceptions import ConfigError
-from ..versions import Version
-from .output import diff, echo_message
+from badabump.enums import ChangeLogTypeEnum, FormatTypeEnum, ProjectTypeEnum
+from badabump.exceptions import ConfigError
+from badabump.versions import Version
 
 
 def find_changelog_path(config: ProjectConfig) -> Path:
@@ -35,6 +35,16 @@ def find_changelog_path(config: ProjectConfig) -> Path:
     return path / default_file
 
 
+def format_version_str(item: Path, version_str: str) -> str:
+    if item.name == "pyproject.toml":
+        return f'version = "{version_str}"'
+
+    if item.name == "package.json":
+        return f'"version": "{version_str}"'
+
+    return version_str
+
+
 def guess_version_files(config: ProjectConfig) -> Tuple[str, ...]:
     if config.project_type == ProjectTypeEnum.javascript:
         return (FILE_PACKAGE_JSON,)
@@ -47,7 +57,7 @@ def guess_version_files(config: ProjectConfig) -> Tuple[str, ...]:
         version_files.append(FILE_PYPROJECT_TOML)
 
         project_name = (
-            toml.loads(maybe_pyproject_toml_path.read_text())
+            tomli.loads(maybe_pyproject_toml_path.read_text())
             .get("tool", {})
             .get("poetry", {})
             .get("name")
@@ -239,11 +249,12 @@ def update_version_files(
         if is_dry_run:
             continue
 
+        item_path = path.joinpath(item)
         updated.add(
             update_file(
-                path.joinpath(item),
-                current_version_str,
-                next_version_str,
+                item_path,
+                format_version_str(item_path, current_version_str),
+                format_version_str(item_path, next_version_str),
             )
         )
 
